@@ -52,7 +52,7 @@ from .aws_s3_streaming_body import AWSS3StreamingBody as AWSS3StreamingBody
 from .aws_s3_tag import AWSs3Tag
 from .aws_s3_transfer_allowed_upload_args import AWSs3TransferAllowedUploadArgs
 from .aws_s3_transfer_config_options import AWSs3TransferConfigOptions
-from .aws_s3_upload_part_copy_options import AWSs3UploadPartCopyOptions
-from .aws_s3_upload_part_copy_response import AWSs3UploadPartCopyResponse
+from .aws_s3_upload_part_copy_request import AWSs3UploadPartCopyRequest as AWSs3UploadPartCopyRequest
+from .aws_s3_upload_part_copy_response import AWSs3UploadPartCopyResponse as AWSs3UploadPartCopyResponse
 from .aws_s3_upload_part_request import AWSs3UploadPartRequest as AWSs3UploadPartRequest
 from .aws_s3_upload_part_response import AWSs3UploadPartResponse as AWSs3UploadPartResponse
\ No newline at end of file
