@@ -2,7 +2,7 @@ from pydantic import BaseModel, StrictStr, StrictBool
 from typing import Literal, Optional
 
 
-class AWSs3DeleteObjectResponse(BaseModel):
+class AWSS3DeleteObjectResponse(BaseModel):
     DeleteMarker: StrictBool
     VersionId: StrictStr
     RequestCharged: Optional[
